pub enum Error {
Show 19 variants
BinaryReader(BinaryReaderError),
BufferOverflow(usize),
ControlStackUnderflow,
DuplicateFunc(u32),
DuplicateJump(u16),
FuncNotFound(u32),
InvalidElseBlock(u16),
InvalidLocalIndex(usize),
InvalidMP(u8),
InvalidPC(usize),
InvalidDepth(usize),
LabelMismatch,
LocalIndexOutOfRange,
LocalNotOnStack(usize),
MemoryOutOfBounds,
StackIndexOutOfRange(u8),
StackOverflow(u8),
StackUnderflow(u8, u8),
StackNotBalanced(u8),
}Expand description
Codegen error
Variants
BinaryReader(BinaryReaderError)
Failed to parse WASM with binary reader.
BufferOverflow(usize)
Failed to push more data to the buffer.
ControlStackUnderflow
Failed to pop control stack frame.
DuplicateFunc(u32)
Failed to register program counter to function index.
DuplicateJump(u16)
Failed to merge jump table.
FuncNotFound(u32)
Failed to find function index in jump table.
InvalidElseBlock(u16)
Failed to mark else block for if block.
InvalidLocalIndex(usize)
Failed to get local with given index.
InvalidMP(u8)
Failed to get the offset of the given memory pointer.
InvalidPC(usize)
Failed to construct program counter for jump.
InvalidDepth(usize)
Failed to get frame info of the given depth.
LabelMismatch
Failed to patch jump destination.
LocalIndexOutOfRange
Failed to define local variable since the index is out of range.
LocalNotOnStack(usize)
Failed to get local variables.
MemoryOutOfBounds
Failed to index data on memory.
StackIndexOutOfRange(u8)
Failed to index data on stack.
StackOverflow(u8)
Failed to increment stack pointer.
StackUnderflow(u8, u8)
Failed to decrement stack pointer.
StackNotBalanced(u8)
Failed to pop stack.